pydmps
======

Dynamic movement primitives (DMPs) are a method of trajectory control / planning from Stefan Schaal’s lab. They were presented way back in 2002 in this paper (http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.142.3886), and then updated in 2013 by Auke Ijspeert in this paper (http://www-clmc.usc.edu/publications/I/ijspeert-NC2013.pdf). This work was motivated by the desire to find a way to represent complex motor actions that can be flexibly adjusted without manual parameter tuning or having to worry about instability.

This repository is a Python implementation of DMPs, with accompanying tutorials and applications that can be found at http://studywolf.wordpress.com/category/robotics/dynamic-movement-primitive/

All that's required for the installation and running of the code is ```numpy```. To run the test code you will also need ```matplotlib``` for displaying the results.
